[Lldb-commits] [lldb] c50817d - [LLDB][NativePDB] Don't create inlined function parameters when it's malformed.

Zequan Wu via lldb-commits lldb-commits at lists.llvm.org
Fri Apr 15 11:59:19 PDT 2022


Author: Zequan Wu
Date: 2022-04-15T11:59:11-07:00
New Revision: c50817d1bea4ac51ed776154014630a439176de6

URL: https://github.com/llvm/llvm-project/commit/c50817d1bea4ac51ed776154014630a439176de6
DIFF: https://github.com/llvm/llvm-project/commit/c50817d1bea4ac51ed776154014630a439176de6.diff

LOG: [LLDB][NativePDB] Don't create inlined function parameters when it's malformed.

Added: 
    

Modified: 
    lldb/source/Plugins/SymbolFile/NativePDB/PdbAstBuilder.cpp

Removed: 
    


################################################################################
diff  --git a/lldb/source/Plugins/SymbolFile/NativePDB/PdbAstBuilder.cpp b/lldb/source/Plugins/SymbolFile/NativePDB/PdbAstBuilder.cpp
index 7370753a33c48..b9c442187d586 100644
--- a/lldb/source/Plugins/SymbolFile/NativePDB/PdbAstBuilder.cpp
+++ b/lldb/source/Plugins/SymbolFile/NativePDB/PdbAstBuilder.cpp
@@ -1285,9 +1285,11 @@ void PdbAstBuilder::CreateFunctionParameters(PdbCompilandSymId func_id,
       break;
     }
     case S_BLOCK32:
-      // All parameters should come before the first block.  If that isn't the
-      // case, then perhaps this is bad debug info that doesn't contain
-      // information about all parameters.
+    case S_INLINESITE:
+    case S_INLINESITE2:
+      // All parameters should come before the first block/inlinesite.  If that
+      // isn't the case, then perhaps this is bad debug info that doesn't
+      // contain information about all parameters.
       return;
     default:
       continue;


        


More information about the lldb-commits mailing list